:mod:`kwant.operator` -- Operators and Observables
==================================================

.. module:: kwant.operator

Observables
-----------
.. autosummary::
   :toctree: generated/
   :template: autosummary/functor.rst

   Density
   Current
   Source
